statecraft library

Support for doing something awesome.

More dartdocs go here.

Classes

AsyncFailure<T>
Represents a failed asynchronous operation with an error message.
AsyncInitial<T>
The initial state before any asynchronous operation has started.
AsyncLoading<T>
Represents an ongoing asynchronous operation.
AsyncState<T>
A sealed class representing an asynchronous state with common phases:
AsyncSuccess<T>
Represents a successful completion of an asynchronous operation.
FormFailure<T>
FormInitial<T>
FormState<T>
FormSubmitting<T>
FormSuccess<T>
PaginationFailure<T>
An error occurred, with existing items preserved.
PaginationInitial<T>
The initial state before any data has been loaded.
PaginationLoaded<T>
Data has been loaded with items, current page, and whether more pages exist.
PaginationLoading<T>
The first page is currently being loaded.
PaginationLoadingMore<T>
Loading the next page while preserving existing items.
PaginationState<T>
A sealed class representing a paginated data state with common phases: